
# 		Loren Williams, Georgia Tech
# 		pymol script for analyzing the complex of the BGL II with DNA
# 		based on PDB entry 1DFM
#
#		Reference
#     	C.M.LUKACS,R.KUCERA,I.SCHILDKRAUT,A.K.AGGARWAL               
#       NDERSTANDING THE IMMUTABILITY OF RESTRICTION                
#       ENZYMES: CRYSTAL STRUCTURE OF BGL II AND ITS DNA              
#       SUBSTRATE AT 1.5 A RESOLUTION.                               
#       NAT.STRUCT.BIOL. V. 7, 134, 2000              

reinitialize
bg_color white


load BGLII_1DFM.pdb, Complex
#remove resn HOH and Complex

create DNA, Complex and Chain C+D 
remove resn HOH and DNA

#-------- carton DNA
create Cartoon_DNA, DNA
set cartoon_ring_mode=2, Cartoon_DNA
hide everything, Cartoon_DNA
set cartoon_tube_radius=0.4, Cartoon_DNA
show cartoon, Cartoon_DNA

#-------- Stick DNA
create Stick_DNA, DNA
hide everything, Stick_DNA
show stick, Stick_DNA
color wheat, (Stick_DNA and name C*)
color red, (Stick_DNA and name O*)
color blue, (Stick_DNA and name N*)
color yelloworange, (Stick_DNA and name P)

#--------------- Watson-Crick hydrogen bonds----------------

distance WC_Hbond, (name O2,N3,N4 and resn DC and Stick_DNA ), (name N2,N1,O6 and resn DG and Stick_DNA ), 3.27
distance WC_Hbond, (name N3,O4 and resn DT and Stick_DNA ), (name N1,N6 and resn DA and Stick_DNA ), 3.27
color black, WC_Hbond
hide labels, WC_Hbond
set dash_width, 3
set dash_gap, 0.4



#-------- Cartoon Protein

create Cartoon_Protein, Complex and Chain A+B
hide everything, Cartoon_Protein
show cartoon, Cartoon_Protein
set cartoon_cylindrical_helices,2, Cartoon_protein
color blue, Cartoon_Protein
color cyan, ss h and Cartoon_Protein
color magenta, ss s and Cartoon_Protein

#--------Stick Protein Protein

create Stick_Protein, Complex and Chain A+B
hide everything, Stick_Protein
show stick, Stick_Protein
color bluewhite, name C* and Stick_Protein
color blue, name N* and Stick_Protein
color red, name O* and Stick_Protein
color yellow, name S* and Stick_Protein


#--------Protein-DNA Hydrogen Bonds

distance H_Bond_DNA_Protein, (Complex and Chain C+D and name O*,N*), (Complex and Chain A+B and name O*,N* ), 3.4
color black, H_Bond_DNA_Protein

#-------- Create Metal Binding Site

create Metal_Complex_A, /Complex//A/CA`701/CA + Complex//C/DA`7/* + /Complex//C/DG`8/* + /Complex//C/DA`9/* + /Complex//A/ASP`84/* + /Complex//A/VAL`94/* + /Complex//A/GLN`95/* + /Complex//A/HOH`722/O + /Complex//A/HOH`841/O + /Complex//C/HOH`30/O

create Metal_Complex_B, /Complex//B/CA`702/CA + Complex//D/DT`22/* + /Complex//D/DA`23/* + /Complex//D/DG`24/* + /Complex//B/ASP`84/* + /Complex//B/VAL`94/* + /Complex//B/GLN`95/* 
  
create sicile_bond, /Complex//E/DA`2/SCC
show nb_sphere, sicile_bond

label sicile_bond, "Sicile Bond"
set label_size, 18, sicile_bond
set label_color, deepteal, sicile_bond
set label_outline_color, black, sicile_bond
set label_shadow_mode=2, sicile_bond


hide everything, Metal_Complex_*
show stick, Metal_Complex_*
show sphere, /Metal_Complex_*//*/CA`70*/CA

color yelloworange, (Metal_Complex_* and name P)
color wheat, (Metal_Complex_* and name C*)
color blue, (Metal_Complex_* and name N*)
color red, (Metal_Complex_* and name O*)
color cyan, /Metal_Complex_*//*/CA`70*/CA

alter /Metal_Complex_*//*/CA`70*/CA, vdw=.6
rebuild

create Metal_Complexes, Metal_Complex_A or Metal_Complex_B

distance metal_coordination, (Metal_Complex_* and name CA and resi 70*), (Metal_Complex_* and name OP1), 3.2
distance metal_coordination, (Metal_Complex_* and name CA and resi 70*), (Metal_Complex_* and resn VAL), 3.2
distance  metal_coordination, (Metal_Complex_* and name CA and resi 70*), /Metal_Complex_*//*/ASP`84/OD2, 3.2
distance metal_coordination, (Metal_Complexes and name CA and resi 70*), (Metal_Complexes and resn HOH), 3.4

color black, metal_coordination
set label_font_id=3, metal_coordination
set dash_width, 5

delete Metal_Complex_*
show nb_sphere, Metal_Complexes
#delete Complex
delete DNA

create nucleophile, Metal_Complexes//A/HOH`722/O
show spheres, nucleophile
alter nucleophile, vdw=0.5
rebuild
label nucleophile, "Nucleophilic Water"

set label_size, 18, nucleophile
set label_color, deepteal, nucleophile
set label_outline_color, black, nucleophile
set label_shadow_mode=2, nucleophile

#---------------------display---------------------
disable all
enable cartoon_DNA
enable stick_DNA
enable Cartoon_Protein
enable WC_Hbond
enable sicile_bond
enable metal_coordination
enable nucleophile
enable Metal_Complexes

set_view (\
    -0.260078609,   -0.168357670,   -0.950816274,\
     0.112287924,   -0.983288467,    0.143392459,\
    -0.959057093,   -0.069472648,    0.274629503,\
     0.000000000,    0.000000000, -151.876159668,\
    26.517349243,   13.552135468,   28.953121185,\
   119.740318298,  184.011993408,  -20.000000000 )
### cut above here and paste into script ###
